sim_and_mr: Simulate U,X and Y and run MR on them

Description Usage Arguments Value

View source: R/simulating.R

Description

Simulates confounder U, exposure X and outcome Y based on genotype data and betacoefficients. For examples see vignette browseVignettes('MRTool')

Usage

1
sim_and_mr(SNP_data, SNP, my_Parameters, reverse = FALSE)

Arguments

reverse=FALSE

TRUE if MR should be conducted with X as putative outcome and Y as putative exposure

Value

list(reg_res,sim_data,mr_res)


askieslinger/MRTool documentation built on April 29, 2020, 12:02 p.m.