Description Usage Arguments Value
Simulates confounder U, exposure X and outcome Y based on genotype data and betacoefficients. For examples see vignette browseVignettes('MRTool')
1 | sim_and_mr(SNP_data, SNP, my_Parameters, reverse = FALSE)
|
reverse=FALSE |
TRUE if MR should be conducted with X as putative outcome and Y as putative exposure |
list(reg_res,sim_data,mr_res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.